==> testsuite-3.0.43-beta1.tar.gz: testsuite/modules/phpstan_tests/src/PhpstanTestsResourceService.php <==
<?php

namespace Drupal\phpstan_tests;

use Drupal\Component\Serialization\Json;
use Drupal\Core\File\FileSystemInterface;
use Drupal\testsuite\BaseService;
use Drupal\testsuite\BaseTrait;

/**
 * Phpstan Tests Services.
 */
class PhpstanTestsResourceService extends BaseService {
  use BaseTrait;

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * Json Serialization.
   *
   * @var \Drupal\Component\Serialization\Json
   */
  protected $json;

  /**
   * PhpstanTestsResourceService constructor.
   *
   * @param \Drupal\Core\File\FileSystemInterface $fileSystem
   *   The file system interface.
   * @param \Drupal\Component\Serialization\Json $json
   *   The file system interface.
   */
  public function __construct(
    FileSystemInterface $fileSystem,
    Json $json
  ) {
    $this->fileSystem = $fileSystem;
    $this->json = $json;
  }

  /**
   * Returns the phpstan report array.
   *
   * @param string $area
   *   The area the module is located. Core, contrib or custom.
   * @param string $module
   *   The module name.
   *
   * @return array
   *   The phpstan report array.
   */
  public function getPhpStanReport($area, $module) {
    if (in_array($area, $this->areas) && preg_match('/[a-z_]+/', $module)) {
      $statement = 'php vendor' . DIRECTORY_SEPARATOR . 'bin' . DIRECTORY_SEPARATOR . 'phpstan.phar analyze --error-format=prettyJson ';
      switch ($area) {
        case 'core':
          $statement .= $this->fileSystem->realpath('core') . DIRECTORY_SEPARATOR . 'modules' . DIRECTORY_SEPARATOR . $module;
          break;

        default:
          $statement .= $this->fileSystem->realpath('modules') . DIRECTORY_SEPARATOR . $area . DIRECTORY_SEPARATOR . $module;
      }
      $reportResults = [];
      $results = $this->getData($statement);
      $result = $this->json->decode($results);
      foreach ($result['files'] as $file => $values) {
        if ($values["errors"] > 0) {
          foreach ($values["messages"] as $item) {
            $ignorable = $item["ignorable"] == TRUE ? "Yes" : "No";
            $message = "Message: " . $item["message"] . "\n";
            $message .= "Line: " . $item["line"] . "\n";
            $message .= "Ignorable: " . $ignorable . "\n";
            if (isset($item["tip"])) {
              $message .= "Tip: " . $item["tip"];
            }
            $reportResults[] = [
              'file' => $file,
              'line' => $item["line"],
              'ignore' => $item["ignorable"] == TRUE ? 1 : 0,
              'error' => $message,
            ];
          }
        }
      }
    }
    else {
      $reportResults[] = [
        'file' => "Invalid Parameter",
        'line' => 1,
        'ignore' => 0,
        'error' => "Invalid Parameter: Module name must contain only leters and underscores. No numbers. No spaces.",
      ];
    }

    return $reportResults;
  }

  /**
   * Gets the array of files to create classes with.
   *
   * @param string $area
   *   The area the module is located. Core, contrib or custom.
   *
   * @return array
   *   The array of modules.
   */
  public function getResource($area) {
    $modules = [];
    switch ($area) {
      case 'core';
        $modules = $this->getModulesByArea($this->fileSystem->realpath('core') . DIRECTORY_SEPARATOR . 'modules');
        break;

      case 'contrib';
        $modules = $this->getModulesByArea($this->fileSystem->realpath('modules') . DIRECTORY_SEPARATOR . 'contrib');
        break;

      case 'custom';
        $modules = $this->getModulesByArea($this->fileSystem->realpath('modules') . DIRECTORY_SEPARATOR . 'custom');
        break;
    }

    return $modules;
  }

}

==> testsuite-3.0.48-beta1.tar.gz: testsuite/modules/phpstan_tests/src/PhpstanTestsResourceService.php <==
<?php

namespace Drupal\phpstan_tests;

use Drupal\Component\Serialization\Json;
use Drupal\Core\File\FileSystemInterface;
use Drupal\testsuite\BaseFileService;
use Drupal\testsuite\BaseTrait;

/**
 * Phpstan Tests Services.
 */
class PhpstanTestsResourceService extends BaseFileService {
  use BaseTrait;

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * Json Serialization.
   *
   * @var \Drupal\Component\Serialization\Json
   */
  protected $json;

  /**
   * PhpstanTestsResourceService constructor.
   *
   * @param \Drupal\Core\File\FileSystemInterface $fileSystem
   *   The file system interface.
   * @param \Drupal\Component\Serialization\Json $json
   *   The file system interface.
   */
  public function __construct(
        FileSystemInterface $fileSystem,
        Json $json
    ) {
    $this->fileSystem = $fileSystem;
    $this->json = $json;
  }

  /**
   * Returns the phpstan report array.
   *
   * @param string $area
   *   The area the module is located. Core, contrib or custom.
   * @param string $module
   *   The module name.
   *
   * @return array
   *   The phpstan report array.
   */
  public function getPhpStanReport($area, $module) {
    if (in_array($area, $this->areas) && preg_match('/[a-z_]+/', $module)) {
      $statement = 'php vendor' . DIRECTORY_SEPARATOR . 'bin' . DIRECTORY_SEPARATOR . 'phpstan.phar analyze -c ' . DRUPAL_ROOT;
      $statement .= DIRECTORY_SEPARATOR . 'core' . DIRECTORY_SEPARATOR . 'phpstan.neon';
      /* switch ($area) {
      case 'core':
      $statement .= $this->fileSystem->realpath('core') . DIRECTORY_SEPARATOR . 'modules' . DIRECTORY_SEPARATOR . $module;
      break;

      default:
      $statement .= $this->fileSystem->realpath('modules') . DIRECTORY_SEPARATOR . $area . DIRECTORY_SEPARATOR . $module;
      } */
      $reportResults = [];
      $results = $this->getData($statement);
      $result = $this->json->decode($results);
      foreach ($result['files'] as $file => $values) {
        if ($values["errors"] > 0) {
          foreach ($values["messages"] as $item) {
            $ignorable = $item["ignorable"] == TRUE ? "Yes" : "No";
            $message = "Message: " . $item["message"] . "\n";
            $message .= "Line: " . $item["line"] . "\n";
            $message .= "Ignorable: " . $ignorable . "\n";
            if (isset($item["tip"])) {
              $message .= "Tip: " . $item["tip"];
            }
            $reportResults[] = [
              'file' => $file,
              'line' => $item["line"],
              'ignore' => $item["ignorable"] == TRUE ? 1 : 0,
              'error' => $message,
            ];
          }
        }
      }
    }
    else {
      $reportResults[] = [
        'file' => "Invalid Parameter",
        'line' => 1,
        'ignore' => 0,
        'error' => "Invalid Parameter: Module name must contain only leters and underscores. No numbers. No spaces.",
      ];
    }

    return $reportResults;
  }

  /**
   * Gets the array of files to create classes with.
   *
   * @param string $area
   *   The area the module is located. Core, contrib or custom.
   *
   * @return array
   *   The array of modules.
   */
  public function getResource($area) {
    $modules = [];
    switch ($area) {
      case 'core';
        $modules = $this->getModulesByArea($this->fileSystem->realpath('core') . DIRECTORY_SEPARATOR . 'modules');
        break;

      case 'contrib';
        $modules = $this->getModulesByArea($this->fileSystem->realpath('modules') . DIRECTORY_SEPARATOR . 'contrib');
        break;

      case 'custom';
        $modules = $this->getModulesByArea($this->fileSystem->realpath('modules') . DIRECTORY_SEPARATOR . 'custom');
        break;
    }

    return $modules;
  }

}
